==> pilotlight_tools-0.4.0.tar.gz: pilotlight_tools-0.4.0/README.md <==

<h1 align="center">
  Pilot Light
</h1>

<p align="center">A lightweight game engine with minimal dependencies.</p>

<h1></h1>

<p align="center">
   <a href="https://github.com/pilot-light/pilotlight/actions?workflow=Build"><img src="https://github.com/pilot-light/pilotlight/workflows/Build/badge.svg?branch=master" alt="build"></a>
   <a href="https://github.com/pilot-light/pilotlight/actions?workflow=Static%20Analysis"><img src="https://github.com/pilot-light/pilotlight/workflows/Static%20Analysis/badge.svg?branch=master" alt="static-analysis"></a>
</p>

<p align="center">
  <a href="#information">Information</a> •
  <a href="#reusable-components">Reusable Components</a> •
  <a href="#developer-notes">Developer Notes</a> • 
  <a href="#license">License</a> •
  <a href="#gallery">Gallery</a> •
  <a href="#inspiration">Inspiration</a>
</p>

## Information
The plan for _Pilot Light_ is to be collection of "[stb](https://github.com/nothings/stb) style" libraries that culminate into a lightweight game engine. Ideally all of the libraries would be completely standalone but this isn't practical for the larger systems so some will rely on others. Beware, this project is still in the early stages.

## Reusable Components
library | latest version | description | required files
--------|----------------|-------------|-----------------
pl_ds | v0.1 WIP       | data structures | pl_ds.h
pl_log | v0.1 WIP      | simple logger | pl_log.h
pl_profile | v0.1 WIP  | simple profiler | pl_profile.h
pl_math | v0.1 WIP | math | pl_math.h, pl_math.inc
pl_memory | v0.1 WIP | memory allocators | pl_memory.h
pl_string | v0.1 WIP | string operations | pl_string.h
pl_io | v0.1 WIP | keyboard/mouse input/output system | pl_io.h, pl_ds.h, pl_math.inc
pl_camera | v0.1 WIP | camera operations | pl_camera.h, pl_math.h, pl_math.inc
pl_os | v0.1 WIP | operating system services | pl_os.h, pl_memory.h, pl_os_*.c
pl_draw | v0.1 WIP | 2D drawing API | pl_draw.h pl_draw.c, pl_ds.h, pl_math.h, pl_math.inc, stb_truetype.h, stb_rect_pack.h, pl_draw_*.c
pl_ui | v0.1 WIP | immediate mode UI | pl_ui.h, pl_ui.c, pl_io.h, pl_string.h, pl_memory.h, pl_draw files above


## Developer Notes
Information for developers can be found in the [wiki](https://github.com/pilot-light/pilotlight/wiki). This includes:
* [building](https://github.com/pilot-light/pilotlight/wiki/Building)
* [contributing](https://github.com/pilot-light/pilotlight/wiki/Contributing)
* [style guide](https://github.com/pilot-light/pilotlight/wiki/Style-Guide)

## License
Pilot Light is licensed under the [MIT License](https://github.com/pilot-light/pilotlight/blob/master/LICENSE).

## Gallery

<h1 align="center">
  <br>
  <a href="https://github.com/hoffstadt/DearPyGui"><img src="https://github.com/pilot-light/pilotlight-assets/blob/master/images/firstimage.PNG" alt="First Image"></a>
</h1>

## Inspiration
This project is inspired by:
* [Omar Cornut](http://www.miracleworld.net/) & [Dear ImGui](https://github.com/ocornut/imgui).
* Casey Muratori & [Handmade Hero](https://handmadehero.org/)
* [Sean Barrett](https://nothings.org/) & his [stb](https://github.com/nothings/stb) libraries
* _The Machinery_ before they were abducted

==> pilotlight_tools-0.5.0.tar.gz: pilotlight_tools-0.5.0/README.md <==

<h1 align="center">
  Pilot Light
</h1>

<p align="center">A lightweight game engine with minimal dependencies.</p>

<h1></h1>

<p align="center">
   <a href="https://github.com/pilot-light/pilotlight/actions?workflow=Build"><img src="https://github.com/pilot-light/pilotlight/workflows/Build/badge.svg?branch=master" alt="build"></a>
   <a href="https://github.com/pilot-light/pilotlight/actions?workflow=Static%20Analysis"><img src="https://github.com/pilot-light/pilotlight/workflows/Static%20Analysis/badge.svg?branch=master" alt="static-analysis"></a>
</p>

<p align="center">
  <a href="#information">Information</a> •
  <a href="#developer-notes">Developer Notes</a> • 
  <a href="#license">License</a> •
  <a href="#gallery">Gallery</a> •
  <a href="#inspiration">Inspiration</a>
</p>

## Information
The plan for _Pilot Light_ is to be collection of "[stb](https://github.com/nothings/stb) style" libraries that culminate into a lightweight game engine. Ideally all of the libraries would be completely standalone but this isn't practical for the larger systems so some will rely on others. Beware, this project is still in the early stages.

## Developer Notes
Information for developers can be found in the [wiki](https://github.com/pilot-light/pilotlight/wiki). This includes:
* [building](https://github.com/pilot-light/pilotlight/wiki/Building)
* [contributing](https://github.com/pilot-light/pilotlight/wiki/Contributing)
* [style guide](https://github.com/pilot-light/pilotlight/wiki/Style-Guide)

## License
Pilot Light is licensed under the [MIT License](https://github.com/pilot-light/pilotlight/blob/master/LICENSE).

## Gallery

<p align="center">
  <a href="https://github.com/pilot-light/pilotlight-assets"><img src="https://github.com/pilot-light/pilotlight-assets/blob/master/images/firstimage.PNG" alt="First Image"></a>
</p>

<p align="center">
  <a href="https://github.com/pilot-light/pilotlight-assets"><img src="https://github.com/pilot-light/pilotlight-assets/blob/master/images/sponza.PNG" alt="First Image"></a>
</p>

## Inspiration
This project is inspired by:
* [Omar Cornut](http://www.miracleworld.net/) & [Dear ImGui](https://github.com/ocornut/imgui).
* Casey Muratori & [Handmade Hero](https://handmadehero.org/)
* [Sean Barrett](https://nothings.org/) & his [stb](https://github.com/nothings/stb) libraries
* _The Machinery_ before they were abducted
